"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../../util");
const tempy = require("tempy");
const write_or_validate_device_cfg_file_1 = require("./write-or-validate-device-cfg-file");
const run_and_catch_1 = require("@carnesen/run-and-catch");
const paths_1 = require("../../paths");
const rimraf_1 = require("rimraf");
describe('Test writeOrValidateDeviceCfgFile', () => {
    let tmpDir;
    beforeAll(async () => {
        tmpDir = tempy.directory();
    });
    afterAll(async () => {
        (0, rimraf_1.rimraf)(tmpDir);
    });
    test("file doesn't exist", async () => {
        const spawner = (0, util_1.JsSpawner)({ path: tmpDir });
        const deviceUuid = '1234';
        await (0, write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid });
        expect(spawner.exists(paths_1.DEVICE_CONFIG_FILE_NAME)).toBeTruthy();
        expect(JSON.parse(await spawner.readFile(paths_1.DEVICE_CONFIG_FILE_NAME))).toStrictEqual({
            systemId: 'production',
            deviceUuid,
        });
    });
    test('File exists but invalid json', async () => {
        const readFileOut = 'not valid json';
        const spawner = (0, util_1.JsSpawner)({ path: tmpDir });
        await spawner.writeFile(paths_1.DEVICE_CONFIG_FILE_NAME, readFileOut);
        const deviceUuid = '1234';
        await (0, write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid });
        expect(spawner.exists(paths_1.DEVICE_CONFIG_FILE_NAME)).toBeTruthy();
        expect(JSON.parse(await spawner.readFile(paths_1.DEVICE_CONFIG_FILE_NAME))).toStrictEqual({
            systemId: 'production',
            deviceUuid,
        });
    });
    test('File exists but invalid contents', async () => {
        const readFileOut = JSON.stringify({
            notAField: 'not a field',
        });
        const spawner = (0, util_1.JsSpawner)({ path: tmpDir });
        await spawner.writeFile(paths_1.DEVICE_CONFIG_FILE_NAME, readFileOut);
        const deviceUuid = '1234';
        await (0, write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid });
        expect(spawner.exists(paths_1.DEVICE_CONFIG_FILE_NAME)).toBeTruthy();
        expect(JSON.parse(await spawner.readFile(paths_1.DEVICE_CONFIG_FILE_NAME))).toStrictEqual({
            systemId: 'production',
            deviceUuid,
        });
    });
    test('File exists with mismatching device UUID', async () => {
        const readFileOut = JSON.stringify({
            systemId: 'production',
            deviceUuid: '5678',
        });
        const spawner = (0, util_1.JsSpawner)({ path: tmpDir });
        await spawner.writeFile(paths_1.DEVICE_CONFIG_FILE_NAME, readFileOut);
        const deviceUuid = '1234';
        const exception = await (0, run_and_catch_1.runAndCatch)(write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile, {
            spawner,
            deviceUuid,
        });
        expect(exception.code).toBe(write_or_validate_device_cfg_file_1.DeviceCfgErrors.TARGET_DEVICE_MISMATCH);
    });
    test('File exists with matching device UUID', async () => {
        const readFileOut = JSON.stringify({
            systemId: 'production',
            deviceUuid: '1234',
        });
        const spawner = (0, util_1.JsSpawner)({ path: tmpDir });
        await spawner.writeFile(paths_1.DEVICE_CONFIG_FILE_NAME, readFileOut);
        const deviceUuid = '1234';
        await (0, write_or_validate_device_cfg_file_1.writeOrValidateDeviceCfgFile)({ spawner, deviceUuid });
        expect(spawner.exists(paths_1.DEVICE_CONFIG_FILE_NAME)).toBeTruthy();
        expect(JSON.parse(await spawner.readFile(paths_1.DEVICE_CONFIG_FILE_NAME))).toStrictEqual({
            systemId: 'production',
            deviceUuid,
        });
    });
});
//# sourceMappingURL=write-or-validate-device-cfg-file.test.js.map